use clap::{ArgMatches, Command};

use crate::cli::CuddleCli;

pub fn build_command(root_cmd: Command, cli: CuddleCli) -> Command {
    if cli.scripts.len() > 0 {
        let execute_cmd_about = "x is your entry into your domains scripts, scripts inherited from parents will also be present here";
        let mut execute_cmd = Command::new("x")
            .about(execute_cmd_about)
            .subcommand_required(true);

        for script in cli.scripts.iter() {
            let action_cmd = Command::new(&script.name).about(&script.name);

            execute_cmd = execute_cmd.subcommand(action_cmd);
        }

        root_cmd.subcommand(execute_cmd)
    } else {
        root_cmd
    }
}

pub fn execute_x(exe_submatch: &ArgMatches, cli: CuddleCli) -> anyhow::Result<()> {
    match exe_submatch.subcommand() {
        Some((name, _action_matches)) => {
            log::trace!(action=name; "running action; name={}", name);
            match cli.scripts.iter().find(|ele| ele.name == name) {
                Some(script) => {
                    script.clone().execute(cli.variables.clone())?;
                    Ok(())
                }
                _ => Err(anyhow::anyhow!("could not find a match")),
            }
        }
        _ => Err(anyhow::anyhow!("could not find a match")),
    }
}
